@@ -53,21 +53,16 @@ class Trainer():
             self.logger = Logger(logger) 
 
         if pretrained:
-            download_weights(**config['pretrain'], quiet=config['quiet'])
-            state_dict = torch.load(config['pretrain']['cached'], map_location=torch.device(self.device))
-
-            for name, param in self.model.named_parameters():
-                if state_dict[name].shape != param.shape:
-                    print('{} missmatching shape'.format(name))
-                    del state_dict[name]
-
-            self.model.load_state_dict(state_dict, strict=False)
+            weight_file = download_weights(**config['pretrain'], quiet=config['quiet'])
+            self.load_weights(weight_file)
 
         self.iter = 0
 
         self.optimizer = ScheduledOptim(
-            Adam(self.model.parameters(), betas=(0.9, 0.98), eps=1e-09),
-            config['transformer']['d_model'], **config['optimizer'])
+            AdamW(self.model.parameters(), betas=(0.9, 0.98), eps=1e-09),
+            #config['transformer']['d_model'], 
+            512,
+            **config['optimizer'])
 
 #        self.criterion = nn.CrossEntropyLoss(ignore_index=0) 
         self.criterion = LabelSmoothingLoss(len(self.vocab), padding_idx=self.vocab.pad, smoothing=0.1)
@@ -134,10 +129,10 @@ class Trainer():
                 print(info)
                 self.logger.log(info)
 
-                self.save_checkpoint(self.checkpoint)
+#                self.save_checkpoint(self.checkpoint)
 
                 if acc_full_seq > best_acc:
-                    self.save_weight(self.export_weights)
+                    self.save_weights(self.export_weights)
                     best_acc = acc_full_seq
 
             
@@ -278,8 +273,19 @@ class Trainer():
 
         torch.save(state, filename)
 
-    
-    def save_weight(self, filename):
+    def load_weights(self, filename):
+        state_dict = torch.load(filename, map_location=torch.device(self.device))
+
+        for name, param in self.model.named_parameters():
+            if name not in state_dict:
+                print('{} not found'.format(name))
+            elif state_dict[name].shape != param.shape:
+                print('{} missmatching shape'.format(name))
+                del state_dict[name]
+
+        self.model.load_state_dict(state_dict, strict=False)
+
+    def save_weights(self, filename):
         path, _ = os.path.split(filename)
         os.makedirs(path, exist_ok=True)
        
@@ -345,6 +351,8 @@ class Trainer():
 
         loss.backward()
         
+        torch.nn.utils.clip_grad_norm_(self.model.parameters(), 1) 
+
         self.optimizer.step()
 
         loss_item = loss.item()
