@@ -1,6 +1,6 @@
 from vietocr.model.cnn import CNN
 from vietocr.model.transformer import LanguageTransformer
-from vietocr.model.seq2seq import Seq2Seq
+from vietocr.model.seq2seqv2 import Seq2Seq
 from torch import nn
 
 class VietOCR(nn.Module):
